@@ -41,24 +41,25 @@ enum class Age: uint8_t
     V15_0 = 7,
     V15_1 = 8,
     V16_0 = 9,
-    V1_1 = 10,
-    V2_0 = 11,
-    V2_1 = 12,
-    V3_0 = 13,
-    V3_1 = 14,
-    V3_2 = 15,
-    V4_0 = 16,
-    V4_1 = 17,
-    V5_0 = 18,
-    V5_1 = 19,
-    V5_2 = 20,
-    V6_0 = 21,
-    V6_1 = 22,
-    V6_2 = 23,
-    V6_3 = 24,
-    V7_0 = 25,
-    V8_0 = 26,
-    V9_0 = 27,
+    V17_0 = 10,
+    V1_1 = 11,
+    V2_0 = 12,
+    V2_1 = 13,
+    V3_0 = 14,
+    V3_1 = 15,
+    V3_2 = 16,
+    V4_0 = 17,
+    V4_1 = 18,
+    V5_0 = 19,
+    V5_1 = 20,
+    V5_2 = 21,
+    V6_0 = 22,
+    V6_1 = 23,
+    V6_2 = 24,
+    V6_3 = 25,
+    V7_0 = 26,
+    V8_0 = 27,
+    V9_0 = 28,
 };
 
 enum class Bidi_Class: uint8_t
@@ -237,7 +238,7 @@ enum class Indic_Positional_Category: uint8_t
     Bottom_And_Right = 2,
     Left = 3,
     Left_And_Right = 4,
-    NA = 5,
+    Not_Applicable = 5,
     Overstruck = 6,
     Right = 7,
     Top = 8,
@@ -444,16 +445,17 @@ enum class Joining_Group: uint8_t
     Teh_Marbuta = 92,
     Teh_Marbuta_Goal = 93,
     Teth = 94,
-    Thin_Yeh = 95,
-    Vertical_Tail = 96,
-    Waw = 97,
-    Yeh = 98,
-    Yeh_Barree = 99,
-    Yeh_With_Tail = 100,
-    Yudh = 101,
-    Yudh_He = 102,
-    Zain = 103,
-    Zhain = 104,
+    Thin_Noon = 95,
+    Thin_Yeh = 96,
+    Vertical_Tail = 97,
+    Waw = 98,
+    Yeh = 99,
+    Yeh_Barree = 100,
+    Yeh_With_Tail = 101,
+    Yudh = 102,
+    Yudh_He = 103,
+    Zain = 104,
+    Zhain = 105,
 };
 
 enum class Joining_Type: uint8_t
@@ -510,12 +512,13 @@ enum class Line_Break: uint8_t
     Regional_Indicator = 39,
     Space = 40,
     Surrogate = 41,
-    Unknown = 42,
-    Virama = 43,
-    Virama_Final = 44,
-    Word_Joiner = 45,
-    ZWJ = 46,
-    ZWSpace = 47,
+    Unambiguous_Hyphen = 42,
+    Unknown = 43,
+    Virama = 44,
+    Virama_Final = 45,
+    Word_Joiner = 46,
+    ZWJ = 47,
+    ZWSpace = 48,
 };
 
 enum class NFC_Quick_Check: uint8_t
@@ -668,164 +671,168 @@ enum class Script: uint8_t
     Bassa_Vah = 11,
     Batak = 12,
     Bengali = 13,
-    Bhaiksuki = 14,
-    Bopomofo = 15,
-    Brahmi = 16,
-    Braille = 17,
-    Buginese = 18,
-    Buhid = 19,
-    Canadian_Aboriginal = 20,
-    Carian = 21,
-    Caucasian_Albanian = 22,
-    Chakma = 23,
-    Cham = 24,
-    Cherokee = 25,
-    Chorasmian = 26,
-    Coptic = 27,
-    Cuneiform = 28,
-    Cypriot = 29,
-    Cypro_Minoan = 30,
-    Cyrillic = 31,
-    Deseret = 32,
-    Devanagari = 33,
-    Dives_Akuru = 34,
-    Dogra = 35,
-    Duployan = 36,
-    Egyptian_Hieroglyphs = 37,
-    Elbasan = 38,
-    Elymaic = 39,
-    Ethiopic = 40,
-    Garay = 41,
-    Georgian = 42,
-    Glagolitic = 43,
-    Gothic = 44,
-    Grantha = 45,
-    Greek = 46,
-    Gujarati = 47,
-    Gunjala_Gondi = 48,
-    Gurmukhi = 49,
-    Gurung_Khema = 50,
-    Han = 51,
-    Hangul = 52,
-    Hanifi_Rohingya = 53,
-    Hanunoo = 54,
-    Hatran = 55,
-    Hebrew = 56,
-    Hiragana = 57,
-    Imperial_Aramaic = 58,
-    Inherited = 59,
-    Inscriptional_Pahlavi = 60,
-    Inscriptional_Parthian = 61,
-    Javanese = 62,
-    Kaithi = 63,
-    Kannada = 64,
-    Katakana = 65,
-    Kawi = 66,
-    Kayah_Li = 67,
-    Kharoshthi = 68,
-    Khitan_Small_Script = 69,
-    Khmer = 70,
-    Khojki = 71,
-    Khudawadi = 72,
-    Kirat_Rai = 73,
-    Lao = 74,
-    Latin = 75,
-    Lepcha = 76,
-    Limbu = 77,
-    Linear_A = 78,
-    Linear_B = 79,
-    Lisu = 80,
-    Lycian = 81,
-    Lydian = 82,
-    Mahajani = 83,
-    Makasar = 84,
-    Malayalam = 85,
-    Mandaic = 86,
-    Manichaean = 87,
-    Marchen = 88,
-    Masaram_Gondi = 89,
-    Medefaidrin = 90,
-    Meetei_Mayek = 91,
-    Mende_Kikakui = 92,
-    Meroitic_Cursive = 93,
-    Meroitic_Hieroglyphs = 94,
-    Miao = 95,
-    Modi = 96,
-    Mongolian = 97,
-    Mro = 98,
-    Multani = 99,
-    Myanmar = 100,
-    Nabataean = 101,
-    Nag_Mundari = 102,
-    Nandinagari = 103,
-    New_Tai_Lue = 104,
-    Newa = 105,
-    Nko = 106,
-    Nushu = 107,
-    Nyiakeng_Puachue_Hmong = 108,
-    Ogham = 109,
-    Ol_Chiki = 110,
-    Ol_Onal = 111,
-    Old_Hungarian = 112,
-    Old_Italic = 113,
-    Old_North_Arabian = 114,
-    Old_Permic = 115,
-    Old_Persian = 116,
-    Old_Sogdian = 117,
-    Old_South_Arabian = 118,
-    Old_Turkic = 119,
-    Old_Uyghur = 120,
-    Oriya = 121,
-    Osage = 122,
-    Osmanya = 123,
-    Pahawh_Hmong = 124,
-    Palmyrene = 125,
-    Pau_Cin_Hau = 126,
-    Phags_Pa = 127,
-    Phoenician = 128,
-    Psalter_Pahlavi = 129,
-    Rejang = 130,
-    Runic = 131,
-    Samaritan = 132,
-    Saurashtra = 133,
-    Sharada = 134,
-    Shavian = 135,
-    Siddham = 136,
-    SignWriting = 137,
-    Sinhala = 138,
-    Sogdian = 139,
-    Sora_Sompeng = 140,
-    Soyombo = 141,
-    Sundanese = 142,
-    Sunuwar = 143,
-    Syloti_Nagri = 144,
-    Syriac = 145,
-    Tagalog = 146,
-    Tagbanwa = 147,
-    Tai_Le = 148,
-    Tai_Tham = 149,
-    Tai_Viet = 150,
-    Takri = 151,
-    Tamil = 152,
-    Tangsa = 153,
-    Tangut = 154,
-    Telugu = 155,
-    Thaana = 156,
-    Thai = 157,
-    Tibetan = 158,
-    Tifinagh = 159,
-    Tirhuta = 160,
-    Todhri = 161,
-    Toto = 162,
-    Tulu_Tigalari = 163,
-    Ugaritic = 164,
-    Vai = 165,
-    Vithkuqi = 166,
-    Wancho = 167,
-    Warang_Citi = 168,
-    Yezidi = 169,
-    Yi = 170,
-    Zanabazar_Square = 171,
+    Beria_Erfe = 14,
+    Bhaiksuki = 15,
+    Bopomofo = 16,
+    Brahmi = 17,
+    Braille = 18,
+    Buginese = 19,
+    Buhid = 20,
+    Canadian_Aboriginal = 21,
+    Carian = 22,
+    Caucasian_Albanian = 23,
+    Chakma = 24,
+    Cham = 25,
+    Cherokee = 26,
+    Chorasmian = 27,
+    Coptic = 28,
+    Cuneiform = 29,
+    Cypriot = 30,
+    Cypro_Minoan = 31,
+    Cyrillic = 32,
+    Deseret = 33,
+    Devanagari = 34,
+    Dives_Akuru = 35,
+    Dogra = 36,
+    Duployan = 37,
+    Egyptian_Hieroglyphs = 38,
+    Elbasan = 39,
+    Elymaic = 40,
+    Ethiopic = 41,
+    Garay = 42,
+    Georgian = 43,
+    Glagolitic = 44,
+    Gothic = 45,
+    Grantha = 46,
+    Greek = 47,
+    Gujarati = 48,
+    Gunjala_Gondi = 49,
+    Gurmukhi = 50,
+    Gurung_Khema = 51,
+    Han = 52,
+    Hangul = 53,
+    Hanifi_Rohingya = 54,
+    Hanunoo = 55,
+    Hatran = 56,
+    Hebrew = 57,
+    Hiragana = 58,
+    Imperial_Aramaic = 59,
+    Inherited = 60,
+    Inscriptional_Pahlavi = 61,
+    Inscriptional_Parthian = 62,
+    Javanese = 63,
+    Kaithi = 64,
+    Kannada = 65,
+    Katakana = 66,
+    Kawi = 67,
+    Kayah_Li = 68,
+    Kharoshthi = 69,
+    Khitan_Small_Script = 70,
+    Khmer = 71,
+    Khojki = 72,
+    Khudawadi = 73,
+    Kirat_Rai = 74,
+    Lao = 75,
+    Latin = 76,
+    Lepcha = 77,
+    Limbu = 78,
+    Linear_A = 79,
+    Linear_B = 80,
+    Lisu = 81,
+    Lycian = 82,
+    Lydian = 83,
+    Mahajani = 84,
+    Makasar = 85,
+    Malayalam = 86,
+    Mandaic = 87,
+    Manichaean = 88,
+    Marchen = 89,
+    Masaram_Gondi = 90,
+    Medefaidrin = 91,
+    Meetei_Mayek = 92,
+    Mende_Kikakui = 93,
+    Meroitic_Cursive = 94,
+    Meroitic_Hieroglyphs = 95,
+    Miao = 96,
+    Modi = 97,
+    Mongolian = 98,
+    Mro = 99,
+    Multani = 100,
+    Myanmar = 101,
+    Nabataean = 102,
+    Nag_Mundari = 103,
+    Nandinagari = 104,
+    New_Tai_Lue = 105,
+    Newa = 106,
+    Nko = 107,
+    Nushu = 108,
+    Nyiakeng_Puachue_Hmong = 109,
+    Ogham = 110,
+    Ol_Chiki = 111,
+    Ol_Onal = 112,
+    Old_Hungarian = 113,
+    Old_Italic = 114,
+    Old_North_Arabian = 115,
+    Old_Permic = 116,
+    Old_Persian = 117,
+    Old_Sogdian = 118,
+    Old_South_Arabian = 119,
+    Old_Turkic = 120,
+    Old_Uyghur = 121,
+    Oriya = 122,
+    Osage = 123,
+    Osmanya = 124,
+    Pahawh_Hmong = 125,
+    Palmyrene = 126,
+    Pau_Cin_Hau = 127,
+    Phags_Pa = 128,
+    Phoenician = 129,
+    Psalter_Pahlavi = 130,
+    Rejang = 131,
+    Runic = 132,
+    Samaritan = 133,
+    Saurashtra = 134,
+    Sharada = 135,
+    Shavian = 136,
+    Siddham = 137,
+    Sidetic = 138,
+    SignWriting = 139,
+    Sinhala = 140,
+    Sogdian = 141,
+    Sora_Sompeng = 142,
+    Soyombo = 143,
+    Sundanese = 144,
+    Sunuwar = 145,
+    Syloti_Nagri = 146,
+    Syriac = 147,
+    Tagalog = 148,
+    Tagbanwa = 149,
+    Tai_Le = 150,
+    Tai_Tham = 151,
+    Tai_Viet = 152,
+    Tai_Yo = 153,
+    Takri = 154,
+    Tamil = 155,
+    Tangsa = 156,
+    Tangut = 157,
+    Telugu = 158,
+    Thaana = 159,
+    Thai = 160,
+    Tibetan = 161,
+    Tifinagh = 162,
+    Tirhuta = 163,
+    Todhri = 164,
+    Tolong_Siki = 165,
+    Toto = 166,
+    Tulu_Tigalari = 167,
+    Ugaritic = 168,
+    Vai = 169,
+    Vithkuqi = 170,
+    Wancho = 171,
+    Warang_Citi = 172,
+    Yezidi = 173,
+    Yi = 174,
+    Zanabazar_Square = 175,
 };
 
 enum class Block: uint16_t
@@ -858,317 +865,325 @@ enum class Block: uint16_t
     Bassa_Vah = 25,
     Batak = 26,
     Bengali = 27,
-    Bhaiksuki = 28,
-    Block_Elements = 29,
-    Bopomofo = 30,
-    Bopomofo_Extended = 31,
-    Box_Drawing = 32,
-    Brahmi = 33,
-    Braille_Patterns = 34,
-    Buginese = 35,
-    Buhid = 36,
-    Byzantine_Musical_Symbols = 37,
-    CJK_Compatibility = 38,
-    CJK_Compatibility_Forms = 39,
-    CJK_Compatibility_Ideographs = 40,
-    CJK_Compatibility_Ideographs_Supplement = 41,
-    CJK_Radicals_Supplement = 42,
-    CJK_Strokes = 43,
-    CJK_Symbols_and_Punctuation = 44,
-    CJK_Unified_Ideographs = 45,
-    CJK_Unified_Ideographs_Extension_A = 46,
-    CJK_Unified_Ideographs_Extension_B = 47,
-    CJK_Unified_Ideographs_Extension_C = 48,
-    CJK_Unified_Ideographs_Extension_D = 49,
-    CJK_Unified_Ideographs_Extension_E = 50,
-    CJK_Unified_Ideographs_Extension_F = 51,
-    CJK_Unified_Ideographs_Extension_G = 52,
-    CJK_Unified_Ideographs_Extension_H = 53,
-    CJK_Unified_Ideographs_Extension_I = 54,
-    Carian = 55,
-    Caucasian_Albanian = 56,
-    Chakma = 57,
-    Cham = 58,
-    Cherokee = 59,
-    Cherokee_Supplement = 60,
-    Chess_Symbols = 61,
-    Chorasmian = 62,
-    Combining_Diacritical_Marks = 63,
-    Combining_Diacritical_Marks_Extended = 64,
-    Combining_Diacritical_Marks_Supplement = 65,
-    Combining_Diacritical_Marks_for_Symbols = 66,
-    Combining_Half_Marks = 67,
-    Common_Indic_Number_Forms = 68,
-    Control_Pictures = 69,
-    Coptic = 70,
-    Coptic_Epact_Numbers = 71,
-    Counting_Rod_Numerals = 72,
-    Cuneiform = 73,
-    Cuneiform_Numbers_and_Punctuation = 74,
-    Currency_Symbols = 75,
-    Cypriot_Syllabary = 76,
-    Cypro_Minoan = 77,
-    Cyrillic = 78,
-    Cyrillic_Extended_A = 79,
-    Cyrillic_Extended_B = 80,
-    Cyrillic_Extended_C = 81,
-    Cyrillic_Extended_D = 82,
-    Cyrillic_Supplement = 83,
-    Deseret = 84,
-    Devanagari = 85,
-    Devanagari_Extended = 86,
-    Devanagari_Extended_A = 87,
-    Dingbats = 88,
-    Dives_Akuru = 89,
-    Dogra = 90,
-    Domino_Tiles = 91,
-    Duployan = 92,
-    Early_Dynastic_Cuneiform = 93,
-    Egyptian_Hieroglyph_Format_Controls = 94,
-    Egyptian_Hieroglyphs = 95,
-    Egyptian_Hieroglyphs_Extended_A = 96,
-    Elbasan = 97,
-    Elymaic = 98,
-    Emoticons = 99,
-    Enclosed_Alphanumeric_Supplement = 100,
-    Enclosed_Alphanumerics = 101,
-    Enclosed_CJK_Letters_and_Months = 102,
-    Enclosed_Ideographic_Supplement = 103,
-    Ethiopic = 104,
-    Ethiopic_Extended = 105,
-    Ethiopic_Extended_A = 106,
-    Ethiopic_Extended_B = 107,
-    Ethiopic_Supplement = 108,
-    Garay = 109,
-    General_Punctuation = 110,
-    Geometric_Shapes = 111,
-    Geometric_Shapes_Extended = 112,
-    Georgian = 113,
-    Georgian_Extended = 114,
-    Georgian_Supplement = 115,
-    Glagolitic = 116,
-    Glagolitic_Supplement = 117,
-    Gothic = 118,
-    Grantha = 119,
-    Greek_Extended = 120,
-    Greek_and_Coptic = 121,
-    Gujarati = 122,
-    Gunjala_Gondi = 123,
-    Gurmukhi = 124,
-    Gurung_Khema = 125,
-    Halfwidth_and_Fullwidth_Forms = 126,
-    Hangul_Compatibility_Jamo = 127,
-    Hangul_Jamo = 128,
-    Hangul_Jamo_Extended_A = 129,
-    Hangul_Jamo_Extended_B = 130,
-    Hangul_Syllables = 131,
-    Hanifi_Rohingya = 132,
-    Hanunoo = 133,
-    Hatran = 134,
-    Hebrew = 135,
-    High_Private_Use_Surrogates = 136,
-    High_Surrogates = 137,
-    Hiragana = 138,
-    IPA_Extensions = 139,
-    Ideographic_Description_Characters = 140,
-    Ideographic_Symbols_and_Punctuation = 141,
-    Imperial_Aramaic = 142,
-    Indic_Siyaq_Numbers = 143,
-    Inscriptional_Pahlavi = 144,
-    Inscriptional_Parthian = 145,
-    Javanese = 146,
-    Kaithi = 147,
-    Kaktovik_Numerals = 148,
-    Kana_Extended_A = 149,
-    Kana_Extended_B = 150,
-    Kana_Supplement = 151,
-    Kanbun = 152,
-    Kangxi_Radicals = 153,
-    Kannada = 154,
-    Katakana = 155,
-    Katakana_Phonetic_Extensions = 156,
-    Kawi = 157,
-    Kayah_Li = 158,
-    Kharoshthi = 159,
-    Khitan_Small_Script = 160,
-    Khmer = 161,
-    Khmer_Symbols = 162,
-    Khojki = 163,
-    Khudawadi = 164,
-    Kirat_Rai = 165,
-    Lao = 166,
-    Latin_Extended_Additional = 167,
-    Latin_Extended_A = 168,
-    Latin_Extended_B = 169,
-    Latin_Extended_C = 170,
-    Latin_Extended_D = 171,
-    Latin_Extended_E = 172,
-    Latin_Extended_F = 173,
-    Latin_Extended_G = 174,
-    Latin_1_Supplement = 175,
-    Lepcha = 176,
-    Letterlike_Symbols = 177,
-    Limbu = 178,
-    Linear_A = 179,
-    Linear_B_Ideograms = 180,
-    Linear_B_Syllabary = 181,
-    Lisu = 182,
-    Lisu_Supplement = 183,
-    Low_Surrogates = 184,
-    Lycian = 185,
-    Lydian = 186,
-    Mahajani = 187,
-    Mahjong_Tiles = 188,
-    Makasar = 189,
-    Malayalam = 190,
-    Mandaic = 191,
-    Manichaean = 192,
-    Marchen = 193,
-    Masaram_Gondi = 194,
-    Mathematical_Alphanumeric_Symbols = 195,
-    Mathematical_Operators = 196,
-    Mayan_Numerals = 197,
-    Medefaidrin = 198,
-    Meetei_Mayek = 199,
-    Meetei_Mayek_Extensions = 200,
-    Mende_Kikakui = 201,
-    Meroitic_Cursive = 202,
-    Meroitic_Hieroglyphs = 203,
-    Miao = 204,
-    Miscellaneous_Mathematical_Symbols_A = 205,
-    Miscellaneous_Mathematical_Symbols_B = 206,
-    Miscellaneous_Symbols = 207,
-    Miscellaneous_Symbols_and_Arrows = 208,
-    Miscellaneous_Symbols_and_Pictographs = 209,
-    Miscellaneous_Technical = 210,
-    Modi = 211,
-    Modifier_Tone_Letters = 212,
-    Mongolian = 213,
-    Mongolian_Supplement = 214,
-    Mro = 215,
-    Multani = 216,
-    Musical_Symbols = 217,
-    Myanmar = 218,
-    Myanmar_Extended_A = 219,
-    Myanmar_Extended_B = 220,
-    Myanmar_Extended_C = 221,
-    NKo = 222,
-    Nabataean = 223,
-    Nag_Mundari = 224,
-    Nandinagari = 225,
-    New_Tai_Lue = 226,
-    Newa = 227,
-    Number_Forms = 228,
-    Nushu = 229,
-    Nyiakeng_Puachue_Hmong = 230,
-    Ogham = 231,
-    Ol_Chiki = 232,
-    Ol_Onal = 233,
-    Old_Hungarian = 234,
-    Old_Italic = 235,
-    Old_North_Arabian = 236,
-    Old_Permic = 237,
-    Old_Persian = 238,
-    Old_Sogdian = 239,
-    Old_South_Arabian = 240,
-    Old_Turkic = 241,
-    Old_Uyghur = 242,
-    Optical_Character_Recognition = 243,
-    Oriya = 244,
-    Ornamental_Dingbats = 245,
-    Osage = 246,
-    Osmanya = 247,
-    Ottoman_Siyaq_Numbers = 248,
-    Pahawh_Hmong = 249,
-    Palmyrene = 250,
-    Pau_Cin_Hau = 251,
-    Phags_pa = 252,
-    Phaistos_Disc = 253,
-    Phoenician = 254,
-    Phonetic_Extensions = 255,
-    Phonetic_Extensions_Supplement = 256,
-    Playing_Cards = 257,
-    Private_Use_Area = 258,
-    Psalter_Pahlavi = 259,
-    Rejang = 260,
-    Rumi_Numeral_Symbols = 261,
-    Runic = 262,
-    Samaritan = 263,
-    Saurashtra = 264,
-    Sharada = 265,
-    Shavian = 266,
-    Shorthand_Format_Controls = 267,
-    Siddham = 268,
-    Sinhala = 269,
-    Sinhala_Archaic_Numbers = 270,
-    Small_Form_Variants = 271,
-    Small_Kana_Extension = 272,
-    Sogdian = 273,
-    Sora_Sompeng = 274,
-    Soyombo = 275,
-    Spacing_Modifier_Letters = 276,
-    Specials = 277,
-    Sundanese = 278,
-    Sundanese_Supplement = 279,
-    Sunuwar = 280,
-    Superscripts_and_Subscripts = 281,
-    Supplemental_Arrows_A = 282,
-    Supplemental_Arrows_B = 283,
-    Supplemental_Arrows_C = 284,
-    Supplemental_Mathematical_Operators = 285,
-    Supplemental_Punctuation = 286,
-    Supplemental_Symbols_and_Pictographs = 287,
-    Supplementary_Private_Use_Area_A = 288,
-    Supplementary_Private_Use_Area_B = 289,
-    Sutton_SignWriting = 290,
-    Syloti_Nagri = 291,
-    Symbols_and_Pictographs_Extended_A = 292,
-    Symbols_for_Legacy_Computing = 293,
-    Symbols_for_Legacy_Computing_Supplement = 294,
-    Syriac = 295,
-    Syriac_Supplement = 296,
-    Tagalog = 297,
-    Tagbanwa = 298,
-    Tags = 299,
-    Tai_Le = 300,
-    Tai_Tham = 301,
-    Tai_Viet = 302,
-    Tai_Xuan_Jing_Symbols = 303,
-    Takri = 304,
-    Tamil = 305,
-    Tamil_Supplement = 306,
-    Tangsa = 307,
-    Tangut = 308,
-    Tangut_Components = 309,
-    Tangut_Supplement = 310,
-    Telugu = 311,
-    Thaana = 312,
-    Thai = 313,
-    Tibetan = 314,
-    Tifinagh = 315,
-    Tirhuta = 316,
-    Todhri = 317,
-    Toto = 318,
-    Transport_and_Map_Symbols = 319,
-    Tulu_Tigalari = 320,
-    Ugaritic = 321,
-    Unified_Canadian_Aboriginal_Syllabics = 322,
-    Unified_Canadian_Aboriginal_Syllabics_Extended = 323,
-    Unified_Canadian_Aboriginal_Syllabics_Extended_A = 324,
-    Vai = 325,
-    Variation_Selectors = 326,
-    Variation_Selectors_Supplement = 327,
-    Vedic_Extensions = 328,
-    Vertical_Forms = 329,
-    Vithkuqi = 330,
-    Wancho = 331,
-    Warang_Citi = 332,
-    Yezidi = 333,
-    Yi_Radicals = 334,
-    Yi_Syllables = 335,
-    Yijing_Hexagram_Symbols = 336,
-    Zanabazar_Square = 337,
-    Znamenny_Musical_Notation = 338,
+    Beria_Erfe = 28,
+    Bhaiksuki = 29,
+    Block_Elements = 30,
+    Bopomofo = 31,
+    Bopomofo_Extended = 32,
+    Box_Drawing = 33,
+    Brahmi = 34,
+    Braille_Patterns = 35,
+    Buginese = 36,
+    Buhid = 37,
+    Byzantine_Musical_Symbols = 38,
+    CJK_Compatibility = 39,
+    CJK_Compatibility_Forms = 40,
+    CJK_Compatibility_Ideographs = 41,
+    CJK_Compatibility_Ideographs_Supplement = 42,
+    CJK_Radicals_Supplement = 43,
+    CJK_Strokes = 44,
+    CJK_Symbols_and_Punctuation = 45,
+    CJK_Unified_Ideographs = 46,
+    CJK_Unified_Ideographs_Extension_A = 47,
+    CJK_Unified_Ideographs_Extension_B = 48,
+    CJK_Unified_Ideographs_Extension_C = 49,
+    CJK_Unified_Ideographs_Extension_D = 50,
+    CJK_Unified_Ideographs_Extension_E = 51,
+    CJK_Unified_Ideographs_Extension_F = 52,
+    CJK_Unified_Ideographs_Extension_G = 53,
+    CJK_Unified_Ideographs_Extension_H = 54,
+    CJK_Unified_Ideographs_Extension_I = 55,
+    CJK_Unified_Ideographs_Extension_J = 56,
+    Carian = 57,
+    Caucasian_Albanian = 58,
+    Chakma = 59,
+    Cham = 60,
+    Cherokee = 61,
+    Cherokee_Supplement = 62,
+    Chess_Symbols = 63,
+    Chorasmian = 64,
+    Combining_Diacritical_Marks = 65,
+    Combining_Diacritical_Marks_Extended = 66,
+    Combining_Diacritical_Marks_Supplement = 67,
+    Combining_Diacritical_Marks_for_Symbols = 68,
+    Combining_Half_Marks = 69,
+    Common_Indic_Number_Forms = 70,
+    Control_Pictures = 71,
+    Coptic = 72,
+    Coptic_Epact_Numbers = 73,
+    Counting_Rod_Numerals = 74,
+    Cuneiform = 75,
+    Cuneiform_Numbers_and_Punctuation = 76,
+    Currency_Symbols = 77,
+    Cypriot_Syllabary = 78,
+    Cypro_Minoan = 79,
+    Cyrillic = 80,
+    Cyrillic_Extended_A = 81,
+    Cyrillic_Extended_B = 82,
+    Cyrillic_Extended_C = 83,
+    Cyrillic_Extended_D = 84,
+    Cyrillic_Supplement = 85,
+    Deseret = 86,
+    Devanagari = 87,
+    Devanagari_Extended = 88,
+    Devanagari_Extended_A = 89,
+    Dingbats = 90,
+    Dives_Akuru = 91,
+    Dogra = 92,
+    Domino_Tiles = 93,
+    Duployan = 94,
+    Early_Dynastic_Cuneiform = 95,
+    Egyptian_Hieroglyph_Format_Controls = 96,
+    Egyptian_Hieroglyphs = 97,
+    Egyptian_Hieroglyphs_Extended_A = 98,
+    Elbasan = 99,
+    Elymaic = 100,
+    Emoticons = 101,
+    Enclosed_Alphanumeric_Supplement = 102,
+    Enclosed_Alphanumerics = 103,
+    Enclosed_CJK_Letters_and_Months = 104,
+    Enclosed_Ideographic_Supplement = 105,
+    Ethiopic = 106,
+    Ethiopic_Extended = 107,
+    Ethiopic_Extended_A = 108,
+    Ethiopic_Extended_B = 109,
+    Ethiopic_Supplement = 110,
+    Garay = 111,
+    General_Punctuation = 112,
+    Geometric_Shapes = 113,
+    Geometric_Shapes_Extended = 114,
+    Georgian = 115,
+    Georgian_Extended = 116,
+    Georgian_Supplement = 117,
+    Glagolitic = 118,
+    Glagolitic_Supplement = 119,
+    Gothic = 120,
+    Grantha = 121,
+    Greek_Extended = 122,
+    Greek_and_Coptic = 123,
+    Gujarati = 124,
+    Gunjala_Gondi = 125,
+    Gurmukhi = 126,
+    Gurung_Khema = 127,
+    Halfwidth_and_Fullwidth_Forms = 128,
+    Hangul_Compatibility_Jamo = 129,
+    Hangul_Jamo = 130,
+    Hangul_Jamo_Extended_A = 131,
+    Hangul_Jamo_Extended_B = 132,
+    Hangul_Syllables = 133,
+    Hanifi_Rohingya = 134,
+    Hanunoo = 135,
+    Hatran = 136,
+    Hebrew = 137,
+    High_Private_Use_Surrogates = 138,
+    High_Surrogates = 139,
+    Hiragana = 140,
+    IPA_Extensions = 141,
+    Ideographic_Description_Characters = 142,
+    Ideographic_Symbols_and_Punctuation = 143,
+    Imperial_Aramaic = 144,
+    Indic_Siyaq_Numbers = 145,
+    Inscriptional_Pahlavi = 146,
+    Inscriptional_Parthian = 147,
+    Javanese = 148,
+    Kaithi = 149,
+    Kaktovik_Numerals = 150,
+    Kana_Extended_A = 151,
+    Kana_Extended_B = 152,
+    Kana_Supplement = 153,
+    Kanbun = 154,
+    Kangxi_Radicals = 155,
+    Kannada = 156,
+    Katakana = 157,
+    Katakana_Phonetic_Extensions = 158,
+    Kawi = 159,
+    Kayah_Li = 160,
+    Kharoshthi = 161,
+    Khitan_Small_Script = 162,
+    Khmer = 163,
+    Khmer_Symbols = 164,
+    Khojki = 165,
+    Khudawadi = 166,
+    Kirat_Rai = 167,
+    Lao = 168,
+    Latin_Extended_Additional = 169,
+    Latin_Extended_A = 170,
+    Latin_Extended_B = 171,
+    Latin_Extended_C = 172,
+    Latin_Extended_D = 173,
+    Latin_Extended_E = 174,
+    Latin_Extended_F = 175,
+    Latin_Extended_G = 176,
+    Latin_1_Supplement = 177,
+    Lepcha = 178,
+    Letterlike_Symbols = 179,
+    Limbu = 180,
+    Linear_A = 181,
+    Linear_B_Ideograms = 182,
+    Linear_B_Syllabary = 183,
+    Lisu = 184,
+    Lisu_Supplement = 185,
+    Low_Surrogates = 186,
+    Lycian = 187,
+    Lydian = 188,
+    Mahajani = 189,
+    Mahjong_Tiles = 190,
+    Makasar = 191,
+    Malayalam = 192,
+    Mandaic = 193,
+    Manichaean = 194,
+    Marchen = 195,
+    Masaram_Gondi = 196,
+    Mathematical_Alphanumeric_Symbols = 197,
+    Mathematical_Operators = 198,
+    Mayan_Numerals = 199,
+    Medefaidrin = 200,
+    Meetei_Mayek = 201,
+    Meetei_Mayek_Extensions = 202,
+    Mende_Kikakui = 203,
+    Meroitic_Cursive = 204,
+    Meroitic_Hieroglyphs = 205,
+    Miao = 206,
+    Miscellaneous_Mathematical_Symbols_A = 207,
+    Miscellaneous_Mathematical_Symbols_B = 208,
+    Miscellaneous_Symbols = 209,
+    Miscellaneous_Symbols_Supplement = 210,
+    Miscellaneous_Symbols_and_Arrows = 211,
+    Miscellaneous_Symbols_and_Pictographs = 212,
+    Miscellaneous_Technical = 213,
+    Modi = 214,
+    Modifier_Tone_Letters = 215,
+    Mongolian = 216,
+    Mongolian_Supplement = 217,
+    Mro = 218,
+    Multani = 219,
+    Musical_Symbols = 220,
+    Myanmar = 221,
+    Myanmar_Extended_A = 222,
+    Myanmar_Extended_B = 223,
+    Myanmar_Extended_C = 224,
+    NKo = 225,
+    Nabataean = 226,
+    Nag_Mundari = 227,
+    Nandinagari = 228,
+    New_Tai_Lue = 229,
+    Newa = 230,
+    Number_Forms = 231,
+    Nushu = 232,
+    Nyiakeng_Puachue_Hmong = 233,
+    Ogham = 234,
+    Ol_Chiki = 235,
+    Ol_Onal = 236,
+    Old_Hungarian = 237,
+    Old_Italic = 238,
+    Old_North_Arabian = 239,
+    Old_Permic = 240,
+    Old_Persian = 241,
+    Old_Sogdian = 242,
+    Old_South_Arabian = 243,
+    Old_Turkic = 244,
+    Old_Uyghur = 245,
+    Optical_Character_Recognition = 246,
+    Oriya = 247,
+    Ornamental_Dingbats = 248,
+    Osage = 249,
+    Osmanya = 250,
+    Ottoman_Siyaq_Numbers = 251,
+    Pahawh_Hmong = 252,
+    Palmyrene = 253,
+    Pau_Cin_Hau = 254,
+    Phags_pa = 255,
+    Phaistos_Disc = 256,
+    Phoenician = 257,
+    Phonetic_Extensions = 258,
+    Phonetic_Extensions_Supplement = 259,
+    Playing_Cards = 260,
+    Private_Use_Area = 261,
+    Psalter_Pahlavi = 262,
+    Rejang = 263,
+    Rumi_Numeral_Symbols = 264,
+    Runic = 265,
+    Samaritan = 266,
+    Saurashtra = 267,
+    Sharada = 268,
+    Sharada_Supplement = 269,
+    Shavian = 270,
+    Shorthand_Format_Controls = 271,
+    Siddham = 272,
+    Sidetic = 273,
+    Sinhala = 274,
+    Sinhala_Archaic_Numbers = 275,
+    Small_Form_Variants = 276,
+    Small_Kana_Extension = 277,
+    Sogdian = 278,
+    Sora_Sompeng = 279,
+    Soyombo = 280,
+    Spacing_Modifier_Letters = 281,
+    Specials = 282,
+    Sundanese = 283,
+    Sundanese_Supplement = 284,
+    Sunuwar = 285,
+    Superscripts_and_Subscripts = 286,
+    Supplemental_Arrows_A = 287,
+    Supplemental_Arrows_B = 288,
+    Supplemental_Arrows_C = 289,
+    Supplemental_Mathematical_Operators = 290,
+    Supplemental_Punctuation = 291,
+    Supplemental_Symbols_and_Pictographs = 292,
+    Supplementary_Private_Use_Area_A = 293,
+    Supplementary_Private_Use_Area_B = 294,
+    Sutton_SignWriting = 295,
+    Syloti_Nagri = 296,
+    Symbols_and_Pictographs_Extended_A = 297,
+    Symbols_for_Legacy_Computing = 298,
+    Symbols_for_Legacy_Computing_Supplement = 299,
+    Syriac = 300,
+    Syriac_Supplement = 301,
+    Tagalog = 302,
+    Tagbanwa = 303,
+    Tags = 304,
+    Tai_Le = 305,
+    Tai_Tham = 306,
+    Tai_Viet = 307,
+    Tai_Xuan_Jing_Symbols = 308,
+    Tai_Yo = 309,
+    Takri = 310,
+    Tamil = 311,
+    Tamil_Supplement = 312,
+    Tangsa = 313,
+    Tangut = 314,
+    Tangut_Components = 315,
+    Tangut_Components_Supplement = 316,
+    Tangut_Supplement = 317,
+    Telugu = 318,
+    Thaana = 319,
+    Thai = 320,
+    Tibetan = 321,
+    Tifinagh = 322,
+    Tirhuta = 323,
+    Todhri = 324,
+    Tolong_Siki = 325,
+    Toto = 326,
+    Transport_and_Map_Symbols = 327,
+    Tulu_Tigalari = 328,
+    Ugaritic = 329,
+    Unified_Canadian_Aboriginal_Syllabics = 330,
+    Unified_Canadian_Aboriginal_Syllabics_Extended = 331,
+    Unified_Canadian_Aboriginal_Syllabics_Extended_A = 332,
+    Vai = 333,
+    Variation_Selectors = 334,
+    Variation_Selectors_Supplement = 335,
+    Vedic_Extensions = 336,
+    Vertical_Forms = 337,
+    Vithkuqi = 338,
+    Wancho = 339,
+    Warang_Citi = 340,
+    Yezidi = 341,
+    Yi_Radicals = 342,
+    Yi_Syllables = 343,
+    Yijing_Hexagram_Symbols = 344,
+    Zanabazar_Square = 345,
+    Znamenny_Musical_Notation = 346,
 };
 
 enum class EastAsianWidth: uint8_t
