@@ -52,6 +52,7 @@ inline std::ostream& operator<<(std::ostream& os, Age value) noexcept
     case Age::V15_0: return os << "V15_0";
     case Age::V15_1: return os << "V15_1";
     case Age::V16_0: return os << "V16_0";
+    case Age::V17_0: return os << "V17_0";
     case Age::V1_1: return os << "V1_1";
     case Age::V2_0: return os << "V2_0";
     case Age::V2_1: return os << "V2_1";
@@ -302,7 +303,7 @@ inline std::ostream& operator<<(std::ostream& os, Indic_Positional_Category valu
     case Indic_Positional_Category::Bottom_And_Right: return os << "Bottom_And_Right";
     case Indic_Positional_Category::Left: return os << "Left";
     case Indic_Positional_Category::Left_And_Right: return os << "Left_And_Right";
-    case Indic_Positional_Category::NA: return os << "NA";
+    case Indic_Positional_Category::Not_Applicable: return os << "Not_Applicable";
     case Indic_Positional_Category::Overstruck: return os << "Overstruck";
     case Indic_Positional_Category::Right: return os << "Right";
     case Indic_Positional_Category::Top: return os << "Top";
@@ -527,6 +528,7 @@ inline std::ostream& operator<<(std::ostream& os, Joining_Group value) noexcept
     case Joining_Group::Teh_Marbuta: return os << "Teh_Marbuta";
     case Joining_Group::Teh_Marbuta_Goal: return os << "Teh_Marbuta_Goal";
     case Joining_Group::Teth: return os << "Teth";
+    case Joining_Group::Thin_Noon: return os << "Thin_Noon";
     case Joining_Group::Thin_Yeh: return os << "Thin_Yeh";
     case Joining_Group::Vertical_Tail: return os << "Vertical_Tail";
     case Joining_Group::Waw: return os << "Waw";
@@ -605,6 +607,7 @@ inline std::ostream& operator<<(std::ostream& os, Line_Break value) noexcept
     case Line_Break::Regional_Indicator: return os << "Regional_Indicator";
     case Line_Break::Space: return os << "Space";
     case Line_Break::Surrogate: return os << "Surrogate";
+    case Line_Break::Unambiguous_Hyphen: return os << "Unambiguous_Hyphen";
     case Line_Break::Unknown: return os << "Unknown";
     case Line_Break::Virama: return os << "Virama";
     case Line_Break::Virama_Final: return os << "Virama_Final";
@@ -817,6 +820,7 @@ inline std::ostream& operator<<(std::ostream& os, Script value) noexcept
     case Script::Bassa_Vah: return os << "Bassa_Vah";
     case Script::Batak: return os << "Batak";
     case Script::Bengali: return os << "Bengali";
+    case Script::Beria_Erfe: return os << "Beria_Erfe";
     case Script::Bhaiksuki: return os << "Bhaiksuki";
     case Script::Bopomofo: return os << "Bopomofo";
     case Script::Brahmi: return os << "Brahmi";
@@ -940,6 +944,7 @@ inline std::ostream& operator<<(std::ostream& os, Script value) noexcept
     case Script::Sharada: return os << "Sharada";
     case Script::Shavian: return os << "Shavian";
     case Script::Siddham: return os << "Siddham";
+    case Script::Sidetic: return os << "Sidetic";
     case Script::SignWriting: return os << "SignWriting";
     case Script::Sinhala: return os << "Sinhala";
     case Script::Sogdian: return os << "Sogdian";
@@ -954,6 +959,7 @@ inline std::ostream& operator<<(std::ostream& os, Script value) noexcept
     case Script::Tai_Le: return os << "Tai_Le";
     case Script::Tai_Tham: return os << "Tai_Tham";
     case Script::Tai_Viet: return os << "Tai_Viet";
+    case Script::Tai_Yo: return os << "Tai_Yo";
     case Script::Takri: return os << "Takri";
     case Script::Tamil: return os << "Tamil";
     case Script::Tangsa: return os << "Tangsa";
@@ -965,6 +971,7 @@ inline std::ostream& operator<<(std::ostream& os, Script value) noexcept
     case Script::Tifinagh: return os << "Tifinagh";
     case Script::Tirhuta: return os << "Tirhuta";
     case Script::Todhri: return os << "Todhri";
+    case Script::Tolong_Siki: return os << "Tolong_Siki";
     case Script::Toto: return os << "Toto";
     case Script::Tulu_Tigalari: return os << "Tulu_Tigalari";
     case Script::Ugaritic: return os << "Ugaritic";
@@ -1013,6 +1020,7 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::Bassa_Vah: return os << "Bassa_Vah";
     case Block::Batak: return os << "Batak";
     case Block::Bengali: return os << "Bengali";
+    case Block::Beria_Erfe: return os << "Beria_Erfe";
     case Block::Bhaiksuki: return os << "Bhaiksuki";
     case Block::Block_Elements: return os << "Block_Elements";
     case Block::Bopomofo: return os << "Bopomofo";
@@ -1040,6 +1048,7 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::CJK_Unified_Ideographs_Extension_G: return os << "CJK_Unified_Ideographs_Extension_G";
     case Block::CJK_Unified_Ideographs_Extension_H: return os << "CJK_Unified_Ideographs_Extension_H";
     case Block::CJK_Unified_Ideographs_Extension_I: return os << "CJK_Unified_Ideographs_Extension_I";
+    case Block::CJK_Unified_Ideographs_Extension_J: return os << "CJK_Unified_Ideographs_Extension_J";
     case Block::Carian: return os << "Carian";
     case Block::Caucasian_Albanian: return os << "Caucasian_Albanian";
     case Block::Chakma: return os << "Chakma";
@@ -1193,6 +1202,7 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::Miscellaneous_Mathematical_Symbols_A: return os << "Miscellaneous_Mathematical_Symbols_A";
     case Block::Miscellaneous_Mathematical_Symbols_B: return os << "Miscellaneous_Mathematical_Symbols_B";
     case Block::Miscellaneous_Symbols: return os << "Miscellaneous_Symbols";
+    case Block::Miscellaneous_Symbols_Supplement: return os << "Miscellaneous_Symbols_Supplement";
     case Block::Miscellaneous_Symbols_and_Arrows: return os << "Miscellaneous_Symbols_and_Arrows";
     case Block::Miscellaneous_Symbols_and_Pictographs: return os << "Miscellaneous_Symbols_and_Pictographs";
     case Block::Miscellaneous_Technical: return os << "Miscellaneous_Technical";
@@ -1251,9 +1261,11 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::Samaritan: return os << "Samaritan";
     case Block::Saurashtra: return os << "Saurashtra";
     case Block::Sharada: return os << "Sharada";
+    case Block::Sharada_Supplement: return os << "Sharada_Supplement";
     case Block::Shavian: return os << "Shavian";
     case Block::Shorthand_Format_Controls: return os << "Shorthand_Format_Controls";
     case Block::Siddham: return os << "Siddham";
+    case Block::Sidetic: return os << "Sidetic";
     case Block::Sinhala: return os << "Sinhala";
     case Block::Sinhala_Archaic_Numbers: return os << "Sinhala_Archaic_Numbers";
     case Block::Small_Form_Variants: return os << "Small_Form_Variants";
@@ -1289,12 +1301,14 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::Tai_Tham: return os << "Tai_Tham";
     case Block::Tai_Viet: return os << "Tai_Viet";
     case Block::Tai_Xuan_Jing_Symbols: return os << "Tai_Xuan_Jing_Symbols";
+    case Block::Tai_Yo: return os << "Tai_Yo";
     case Block::Takri: return os << "Takri";
     case Block::Tamil: return os << "Tamil";
     case Block::Tamil_Supplement: return os << "Tamil_Supplement";
     case Block::Tangsa: return os << "Tangsa";
     case Block::Tangut: return os << "Tangut";
     case Block::Tangut_Components: return os << "Tangut_Components";
+    case Block::Tangut_Components_Supplement: return os << "Tangut_Components_Supplement";
     case Block::Tangut_Supplement: return os << "Tangut_Supplement";
     case Block::Telugu: return os << "Telugu";
     case Block::Thaana: return os << "Thaana";
@@ -1303,6 +1317,7 @@ inline std::ostream& operator<<(std::ostream& os, Block value) noexcept
     case Block::Tifinagh: return os << "Tifinagh";
     case Block::Tirhuta: return os << "Tirhuta";
     case Block::Todhri: return os << "Todhri";
+    case Block::Tolong_Siki: return os << "Tolong_Siki";
     case Block::Toto: return os << "Toto";
     case Block::Transport_and_Map_Symbols: return os << "Transport_and_Map_Symbols";
     case Block::Tulu_Tigalari: return os << "Tulu_Tigalari";
